@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
   Copyright (c) 2013 Jonathan Marten <jjm@keelhaul.me.uk>
 
   This program is free software; you can redistribute it and/or modify it
@@ -54,7 +54,7 @@ CollectionExpiryPage::~CollectionExpiryPage()
 bool CollectionExpiryPage::canHandle(const Akonadi::Collection &col) const
 {
     QSharedPointer<FolderSettings> fd = FolderSettings::forCollection(col, false);
-    return fd->canDeleteMessages() && !fd->isStructural();
+    return fd->canDeleteMessages() && !fd->isStructural() && !MailCommon::Util::isVirtualCollection(col);
 }
 
 void CollectionExpiryPage::init()
@@ -96,7 +96,7 @@ void CollectionExpiryPage::init()
     actionsGroup->setFlat(true); // for mutual exclusion of the radio buttons
 
     QHBoxLayout *moveToHBox = new QHBoxLayout();
-    moveToHBox->setMargin(0);
+    moveToHBox->setContentsMargins(0, 0, 0, 0);
     moveToHBox->setSpacing(6);
 
     moveToRB = new QRadioButton(actionsGroup);
@@ -180,9 +180,8 @@ void CollectionExpiryPage::save(Akonadi::Collection &collection)
     }
 }
 
-void CollectionExpiryPage::saveAndExpire(Akonadi::Collection &collection, bool saveSettings, bool _expireNow)
+void CollectionExpiryPage::saveAndExpire(Akonadi::Collection &collection, bool saveSettings, bool expireNow)
 {
-    bool expireNow = _expireNow;
     bool enableGlobally = expireReadMailCB->isChecked() || expireUnreadMailCB->isChecked();
     const Akonadi::Collection expireToFolder = folderSelector->collection();
     if (enableGlobally && moveToRB->isChecked() && !expireToFolder.isValid()) {
